summaryrefslogtreecommitdiff
path: root/src/mongo/db/repl/oplog_entry.h
diff options
context:
space:
mode:
authorAndrew Chen <andrew.chen@10gen.com>2020-03-04 16:50:20 -0500
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2020-03-04 22:25:41 +0000
commit9557a35b779a5f6c1a2453514ec9cc67119b288b (patch)
treeb20574eb806c826ec75ce237540bb1b1950f5386 /src/mongo/db/repl/oplog_entry.h
parent82424b742342d4b35cf10eb9d471984d1e805210 (diff)
downloadmongo-9557a35b779a5f6c1a2453514ec9cc67119b288b.tar.gz
SERVER-45565: Modified Oplog Batcher behavior to process large transaction oplog entries in separate batches
create mode 100644 jstests/noPassthrough/large_txn_correctness.js
Diffstat (limited to 'src/mongo/db/repl/oplog_entry.h')
-rw-r--r--src/mongo/db/repl/oplog_entry.h16
1 files changed, 13 insertions, 3 deletions
diff --git a/src/mongo/db/repl/oplog_entry.h b/src/mongo/db/repl/oplog_entry.h
index d17c0a4c512..9f4d6c5ba0c 100644
--- a/src/mongo/db/repl/oplog_entry.h
+++ b/src/mongo/db/repl/oplog_entry.h
@@ -317,6 +317,11 @@ public:
}
/**
+ * Returns whether if the oplog entry is the last applyOps in a multiple-entry transaction.
+ */
+ bool isEndOfLargeTransaction() const;
+
+ /**
* Returns if this is a prepared 'commitTransaction' oplog entry.
*/
bool isPreparedCommit() const {
@@ -334,10 +339,15 @@ public:
}
/**
- * Returns whether the oplog entry represents an applyOps with a commnd inside. This will occur
- * if a multi-document transaction performs a command.
+ * Returns whether the oplog entry represents a single oplog entry transaction.
+ */
+ bool isSingleOplogEntryTransaction() const;
+
+ /**
+ * Returns whether the oplog entry represents an applyOps with a command inside. This is only
+ * for transactions with only one oplog entry.
*/
- bool isTransactionWithCommand() const;
+ bool isSingleOplogEntryTransactionWithCommand() const;
/**
* Returns if the oplog entry is for a CRUD operation.